@@ -1,6 +1,6 @@
 # Info.pm: output tree as Info.
 #
-# Copyright 2010, 2011, 2012 Free Software Foundation, Inc.
+# Copyright 2010, 2011, 2012, 2013, 2014, 2015 Free Software Foundation, Inc.
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -45,12 +45,15 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 @EXPORT = qw(
 );
 
-$VERSION = '5.0';
+$VERSION = '6.2';
 
 my $STDIN_DOCU_NAME = 'stdin';
 
 my %defaults = Texinfo::Convert::Plaintext::converter_defaults(undef, undef);
 $defaults{'SHOW_MENU'} = 1;
+$defaults{'EXTENSION'} = 'info';
+$defaults{'USE_SETFILENAME_EXTENSION'} = 1;
+$defaults{'OUTFILE'} = undef;
 
 sub converter_defaults($$)
 {
@@ -76,19 +79,23 @@ sub output($)
   push @{$self->{'count_context'}}, {'lines' => 0, 'bytes' => 0,
                                      'locations' => []};
   my $header = $self->_info_header();
+  # header + text between setfilename and first node
+  my $complete_header = $header;
 
   pop @{$self->{'count_context'}};
   return undef unless $self->_create_destination_directory();
 
   my $header_bytes = $self->count_bytes($header);
+  my $complete_header_bytes = $header_bytes;
   my $elements = Texinfo::Structuring::split_by_node($root);
 
   my $fh;
   if (! $self->{'output_file'} eq '') {
-    $fh = $self->Texinfo::Common::open_out($self->{'output_file'});
+    if ($self->get_conf('VERBOSE')) {
+      print STDERR "Output file $self->{'output_file'}\n";
+    }
+    $fh = _open_info_file($self, $self->{'output_file'});
     if (!$fh) {
-      $self->document_error(sprintf($self->__("could not open %s for writing: %s"),
-                                    $self->{'output_file'}, $!));
       return undef;
     }
   }
@@ -117,22 +124,29 @@ sub output($)
                             $self->{'info'}->{'input_file_name'});
     }
     $out_file_nr = 1;
-    if ($fh) {
-      print $fh $header;
-    } else {
-      $result = $header;
-    }
+    my $first_node = 0;
     $self->{'count_context'}->[-1]->{'bytes'} += $header_bytes;
-    my $first_node_bytes_count = $header_bytes;
     my @nodes = @$elements;
     while (@nodes) {
       my $node = shift @nodes;
-      my $node_text = $self->_convert_node($node);
+      my $node_text = $self->_convert_element($node);
+      if (!$first_node) {
+        $first_node = 1;
+        if (defined($self->{'text_before_first_node'})) {
+          $complete_header .= $self->{'text_before_first_node'};
+          $complete_header_bytes += $self->count_bytes($self->{'text_before_first_node'});
+        }
+        # for the first node, header is prepended, not complete_header
+        # as 'text_before_first_node' is already part of the node
+        # text
+        $node_text = $header . $node_text;
+      }
       if ($fh) {
         print $fh $node_text;
       } else {
         $result .= $node_text;
       }
+      $self->_update_count_context();
       if (defined($self->get_conf('SPLIT_SIZE')) 
           and $self->{'count_context'}->[-1]->{'bytes'} > 
                   $out_file_nr * $self->get_conf('SPLIT_SIZE') 
@@ -148,6 +162,10 @@ sub output($)
                                   $self->{'output_file'}, $close_error));
             return undef;
           }
+          if ($self->get_conf('VERBOSE')) {
+            print STDERR "Renaming first output file as ".
+                  $self->{'output_file'}.'-'.$out_file_nr."\n";
+          }
           unless (rename($self->{'output_file'}, 
                          $self->{'output_file'}.'-'.$out_file_nr)) {
             $self->document_error(sprintf($self->__("rename %s failed: %s"),
@@ -161,7 +179,7 @@ sub output($)
           push @{$self->{'opened_files'}}, 
                    $self->{'output_file'}.'-'.$out_file_nr;
           push @indirect_files, [$self->{'output_filename'}.'-'.$out_file_nr,
-                                 $first_node_bytes_count];
+                                 $complete_header_bytes];
           #print STDERR join(' --> ', @{$indirect_files[-1]}) ."\n";
         } else {
           $self->register_close_file($self->{'output_file'}.'-'.$out_file_nr);
@@ -173,16 +191,17 @@ sub output($)
           }
         }
         $out_file_nr++;
-        $fh = $self->Texinfo::Common::open_out (
-                               $self->{'output_file'}.'-'.$out_file_nr); 
-        if (!$fh) {
-           $self->document_error(sprintf(
-                  $self->__("could not open %s for writing: %s"),
-                  $self->{'output_file'}.'-'.$out_file_nr, $!));
-           return undef;
+        if ($self->get_conf('VERBOSE')) {
+          print STDERR "New output file ".
+                $self->{'output_file'}.'-'.$out_file_nr."\n";
         }
-        print $fh $header;
-        $self->{'count_context'}->[-1]->{'bytes'} += $header_bytes;
+        $fh = _open_info_file($self, $self->{'output_file'}.'-'.$out_file_nr); 
+        if (!$fh) {
+          return undef;
+        }
+        print $fh $complete_header;
+        $self->_update_count_context();
+        $self->{'count_context'}->[-1]->{'bytes'} += $complete_header_bytes;
         push @indirect_files, [$self->{'output_filename'}.'-'.$out_file_nr,
                                $self->{'count_context'}->[-1]->{'bytes'}];
         #print STDERR join(' --> ', @{$indirect_files[-1]}) ."\n";
@@ -197,14 +216,14 @@ sub output($)
                             $self->{'output_file'}.'-'.$out_file_nr, $!));
       return undef;
     }
-    $fh = $self->Texinfo::Common::open_out($self->{'output_file'});
+    if ($self->get_conf('VERBOSE')) {
+      print STDERR "Outputing the split manual file $self->{'output_file'}\n";
+    }
+    $fh = _open_info_file($self, $self->{'output_file'});
     if (!$fh) {
-      $self->document_error(sprintf(
-            $self->__("could not open %s for writing: %s"),
-            $self->{'output_file'}, $!));
       return undef;
     }
-    $tag_text = $header;
+    $tag_text = $complete_header;
     $tag_text .= "\x{1F}\nIndirect:";
     foreach my $indirect (@indirect_files) {
       $tag_text .= "\n$indirect->[0]: $indirect->[1]";
@@ -236,10 +255,7 @@ sub output($)
       }
       $prefix = 'Ref';
     }
-    push @{$self->{'count_context'}}, {'lines' => 0, 'bytes' => 0};
-    my $label_text = _normalize_top_node($self->convert_line({'type' => '_code',
-      'contents' => $label->{'root'}->{'extra'}->{'node_content'}}));
-    pop @{$self->{'count_context'}};
+    my ($label_text, $byte_count) = $self->_node_line($label->{'root'});
     $tag_text .=  "$prefix: $label_text\x{7F}$label->{'bytes'}\n";
   }
   $tag_text .=  "\x{1F}\nEnd Tag Table\n";
@@ -266,6 +282,23 @@ sub output($)
   return $result;
 }
 
+# Wrapper around Texinfo::Common::open_out.  Open the file with any CR-LF
+# conversion disabled.  We need this for tag tables to be correct under
+# MS-Windows.   Return filehandle or undef on failure.
+sub _open_info_file($$)
+{
+  my $self = shift;
+  my $filename = shift;
+  my $fh = $self->Texinfo::Common::open_out($filename, undef, 'use_binmode');
+  if (!$fh) {
+    $self->document_error(sprintf(
+        $self->__("could not open %s for writing: %s"),
+        $filename, $!));
+    return undef;
+  }
+  return $fh;
+}
+
 sub _info_header($)
 {
   my $self = shift;
@@ -348,12 +381,6 @@ sub _error_outside_of_any_node($$)
   }
 }
 
-sub _normalize_top_node($)
-{
-  my $node = shift;
-  return Texinfo::Common::normalize_top_node_name($node);
-}
-
 my @directions = ('Next', 'Prev', 'Up');
 sub _node($$)
 {
@@ -365,6 +392,13 @@ sub _node($$)
   if (!$self->{'empty_lines_count'}) {
     $result .= "\n";
     $self->_add_text_count("\n");
+    # if in the first node, complete the 'text_before_first_node' too.
+    if (!$self->{'first_node_done'}) {
+      $self->{'text_before_first_node'} .= "\n";
+    }
+  }
+  if (!$self->{'first_node_done'}) {
+    $self->{'first_node_done'} = 1;
   }
 
   # May happen when only converting a fragment
@@ -379,9 +413,23 @@ sub _node($$)
   my $node_begin = "\x{1F}\nFile: $output_filename,  Node: ";
   $result .= $node_begin;
   $self->_add_text_count($node_begin);
-  my $node_text = _normalize_top_node($self->convert_line({'type' => '_code',
-                           'contents' => $node->{'extra'}->{'node_content'}}));
-  $result .= $node_text;
+  my ($node_text, $byte_count) = $self->_node_line($node);
+  my $pre_quote = '';
+  my $post_quote = '';
+  if ($node_text =~ /,/) {
+    if ($self->get_conf('INFO_SPECIAL_CHARS_WARNING')) {
+      $self->line_warn(sprintf($self->__(
+                 "\@node name should not contain `,': %s"), $node_text),
+                               $node->{'line_nr'});
+    }
+    if ($self->get_conf('INFO_SPECIAL_CHARS_QUOTE')) {
+      $pre_quote = "\x{7f}";
+      $post_quote = $pre_quote;
+      $self->{'count_context'}->[-1]->{'bytes'} += 2;
+    }
+  }
+  $self->{'count_context'}->[-1]->{'bytes'} += $byte_count;
+  $result .= $pre_quote . $node_text . $post_quote;
   foreach my $direction(@directions) {
     if ($node->{'node_'.lc($direction)}) {
       my $node_direction = $node->{'node_'.lc($direction)};
@@ -395,8 +443,9 @@ sub _node($$)
                                           {'text' => ')'}]});
       }
       if ($node_direction->{'extra'}->{'node_content'}) {
-        $result .= _normalize_top_node($self->convert_line({'type' => '_code',
-                 'contents' => $node_direction->{'extra'}->{'node_content'}}));
+        my ($node_text, $byte_count) = $self->_node_line($node_direction);
+        $self->{'count_context'}->[-1]->{'bytes'} += $byte_count;
+        $result .= $node_text;
       }
     }
   }
@@ -481,6 +530,7 @@ sub _image($$)
 1;
 
 __END__
+# $Id: template.pod 6140 2015-02-22 23:34:38Z karl $
 # Automatically generated from maintain/template.pod
 
 =head1 NAME
@@ -493,6 +543,8 @@ Texinfo::Convert::Info - Convert Texinfo tree to Info
     = Texinfo::Convert::Info->converter({'parser' => $parser});
 
   $converter->output($tree);
+  $converter->convert($tree);
+  $converter->convert_tree($tree);
 
 =head1 DESCRIPTION
 
@@ -504,7 +556,7 @@ Texinfo::Convert::Info converts a Texinfo tree to Info.
 
 =item $converter = Texinfo::Convert::Info->converter($options)
 
-Initialize an Info converter.  
+Initialize converter from Texinfo to Info.  
 
 The I<$options> hash reference holds options for the converter.  In
 this option hash reference a parser object may be associated with the 
@@ -527,14 +579,8 @@ the resulting output.
 =item $result = $converter->convert_tree($tree)
 
 Convert a Texinfo tree portion I<$tree> and return the resulting 
-output.  This function do not try to output a full document but only
-portions of document.  For a full document use C<convert>.
-
-=item $result = $converter->output_internal_links()
-
-Returns text representing the links in the document.  At present the format 
-should follow the C<--internal-links> option of texi2any/makeinfo specification
-and this is only relevant for HTML.
+output.  This function does not try to output a full document but only
+portions.  For a full document use C<convert>.
 
 =back
 
@@ -544,7 +590,7 @@ Patrice Dumas, E<lt>pertusus@free.frE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2012 Free Software Foundation, Inc.
+Copyright 2015 Free Software Foundation, Inc.
 
 This library is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
