@@ -36,6 +36,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
           {
             'contents' => [
               {
+                'parent' => {},
                 'text' => ' ',
                 'type' => 'empty_spaces_before_argument'
               },
@@ -50,6 +51,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
           {
             'contents' => [
               {
+                'parent' => {},
                 'text' => ' ',
                 'type' => 'empty_spaces_before_argument'
               },
@@ -68,6 +70,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
                   {
                     'contents' => [
                       {
+                        'parent' => {},
                         'text' => ' ',
                         'type' => 'empty_spaces_before_argument'
                       },
@@ -92,11 +95,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
                               {}
                             ]
                           ],
-                          'normalized' => 'GNU',
-                          'spaces_before_argument' => {
-                            'text' => '',
-                            'type' => 'empty_spaces_before_argument'
-                          }
+                          'explanation_contents' => []
                         },
                         'line_nr' => {
                           'file_name' => '',
@@ -125,12 +124,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
                       {},
                       {}
                     ]
-                  ],
-                  'normalized' => 'GNU',
-                  'spaces_before_argument' => {
-                    'text' => '',
-                    'type' => 'empty_spaces_before_argument'
-                  }
+                  ]
                 },
                 'line_nr' => {},
                 'parent' => {}
@@ -146,6 +140,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
           {
             'contents' => [
               {
+                'parent' => {},
                 'text' => ' ',
                 'type' => 'empty_spaces_before_argument'
               },
@@ -164,6 +159,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
                   {
                     'contents' => [
                       {
+                        'parent' => {},
                         'text' => ' ',
                         'type' => 'empty_spaces_before_argument'
                       },
@@ -188,12 +184,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
                               {}
                             ]
                           ],
-                          'explanation_contents' => [],
-                          'normalized' => 'GNU',
-                          'spaces_before_argument' => {
-                            'text' => '',
-                            'type' => 'empty_spaces_before_argument'
-                          }
+                          'explanation_contents' => []
                         },
                         'line_nr' => {},
                         'parent' => {}
@@ -218,12 +209,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
                       {},
                       {}
                     ]
-                  ],
-                  'normalized' => 'GNU',
-                  'spaces_before_argument' => {
-                    'text' => '',
-                    'type' => 'empty_spaces_before_argument'
-                  }
+                  ]
                 },
                 'line_nr' => {},
                 'parent' => {}
@@ -493,6 +479,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
           {
             'contents' => [
               {
+                'parent' => {},
                 'text' => ' ',
                 'type' => 'empty_spaces_before_argument'
               }
@@ -503,6 +490,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
           {
             'contents' => [
               {
+                'parent' => {},
                 'text' => ' ',
                 'type' => 'empty_spaces_before_argument'
               },
@@ -517,6 +505,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
           {
             'contents' => [
               {
+                'parent' => {},
                 'text' => ' ',
                 'type' => 'empty_spaces_before_argument'
               },
@@ -535,6 +524,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
                   {
                     'contents' => [
                       {
+                        'parent' => {},
                         'text' => ' ',
                         'type' => 'empty_spaces_before_argument'
                       },
@@ -559,12 +549,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
                               {}
                             ]
                           ],
-                          'explanation_contents' => [],
-                          'normalized' => 'GNU',
-                          'spaces_before_argument' => {
-                            'text' => '',
-                            'type' => 'empty_spaces_before_argument'
-                          }
+                          'explanation_contents' => []
                         },
                         'line_nr' => {
                           'file_name' => '',
@@ -593,12 +578,7 @@ $result_trees{'non_automatic_top_node_up_and_url'} = [
                       {},
                       {}
                     ]
-                  ],
-                  'normalized' => 'GNU',
-                  'spaces_before_argument' => {
-                    'text' => '',
-                    'type' => 'empty_spaces_before_argument'
-                  }
+                  ]
                 },
                 'line_nr' => {},
                 'parent' => {}
@@ -664,10 +644,13 @@ $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[0]{
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1];
+$result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[1];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[1];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[1]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1];
+$result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1]{'args'}[0];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1];
+$result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1]{'args'}[1];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1]{'args'}[1]{'contents'}[1];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1]{'args'}[1]{'contents'}[1]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
@@ -681,8 +664,10 @@ $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[1]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'contents'}[2]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[2]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1];
+$result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[3];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[3]{'contents'}[1]{'args'}[0];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[3]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[3]{'contents'}[1];
+$result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[3]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[3]{'contents'}[1]{'args'}[1];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[3]{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[3]{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[3]{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[3]{'contents'}[1]{'args'}[1]{'contents'}[1];
 $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[3]{'contents'}[1]{'args'}[1]{'contents'}[1]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'non_automatic_top_node_up_and_url'}[0]{'contents'}[1]{'args'}[3]{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
@@ -750,11 +735,15 @@ $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[0]{
 $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[0];
 $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[0];
 $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0];
+$result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[1];
 $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0];
+$result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[2];
 $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[2]{'contents'}[1]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[2];
 $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[2]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0];
+$result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[3];
 $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'args'}[0];
 $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1];
+$result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'args'}[1];
 $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'args'}[1]{'contents'}[1];
 $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'args'}[1]{'contents'}[1]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'non_automatic_top_node_up_and_url'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
@@ -1052,9 +1041,8 @@ pre.smalldisplay {font-family: inherit; font-size: smaller}
 pre.smallexample {font-size: smaller}
 pre.smallformat {font-family: inherit; font-size: smaller}
 pre.smalllisp {font-size: smaller}
-span.nocodebreak {white-space: nowrap}
 span.nolinebreak {white-space: nowrap}
-span.roman {font-family: serif; font-weight: normal}
+span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
 ul.no-bullet {list-style: none}
 -->
