@@ -70,9 +70,11 @@ $result_trees{'definfoenclose_on_table_line'} = {
             },
             {
               'cmdname' => 'phi',
+              'contents' => [],
               'extra' => {
                 'begin' => ':',
-                'end' => ':'
+                'end' => ':',
+                'invalid_nesting' => 1
               },
               'parent' => {},
               'type' => 'definfoenclose_command'
